@@ -698,7 +698,8 @@ class Config(dict):
             raise RuntimeError('The environment variable %r is not set '
                                'and as such configuration could not be '
                                'loaded.  Set this variable and make it '
-                               'point to a configuration file')
+                               'point to a configuration file' %
+                               variable_name)
         self.from_pyfile(rv)
         return True
 
@@ -1423,8 +1424,3 @@ current_app = LocalProxy(lambda: _request_ctx_stack.top.app)
 request = LocalProxy(lambda: _request_ctx_stack.top.request)
 session = LocalProxy(lambda: _request_ctx_stack.top.session)
 g = LocalProxy(lambda: _request_ctx_stack.top.g)
-
-
-# script interface to run a development server
-if __name__ == '__main__':
-    sys.exit(main(sys.argv))
